@@ -12,7 +12,7 @@ def get_group_name(user_id: int):
     return f"notify-{user_id}"
 
 
-def get_notification_backend(msg_type: str):
+def get_notification_backend_class(msg_type):
     """
     Get notification backend.
     """
